"""The module that holds metadata about this library."""

from ._version import __version__, __revision__

__package_name__ = 'helium-commander'
__title__ = 'helium'
__author__ = 'Helium'
__author_email__ = 'hello@helium.com'
__license__ = 'BSD'
__copyright__ = 'Copyright 2016 Helium'
__url__ = 'http://github.com/helium/helium-commander'

__all__ = (
    '__package_name__', '__title__', '__author__', '__author_email__',
    '__license__', '__copyright__', '__version__', '__revision__',
    '__url__',
)
